@@ -1,78 +1,54 @@
 package Dist::Joseki::Cmd::Command::tagcheck;
-
 use strict;
 use warnings;
 use Dist::Joseki::SVK;
 use ShipIt::Conf;
-
-
-our $VERSION = '0.17';
-
-
+our $VERSION = '0.18';
 use base 'Dist::Joseki::Cmd::Multiplexable';
-
-
 sub usage_desc { 'tagcheck %o' }
 
-
 sub options {
     my ($self, $app, $cmd_config) = @_;
     return (
         $self->SUPER::options($app, $cmd_config),
-        [
-            'tagbase|b=s',
+        [   'tagbase|b=s',
             'depot path where tagged versions are',
+
             # no defaults here, they are more complicated. see get_tagbase()
         ],
-
-        [
-            'file|f=s',
+        [   'file|f=s',
             'location of the Changes file',
             { default => $cmd_config->{file} || 'Changes' },
         ],
-
-        [
-            'verbose|v',
-            'be verbose',
-            { default => 0 },
-        ],
+        [ 'verbose|v', 'be verbose', { default => 0 }, ],
     );
 }
 
-
 sub get_tagbase {
     my $self = shift;
-
     return $self->opt('tagbase') if defined $self->opt('tagbase');
-
     my $shipit_conf = ShipIt::Conf->parse('.shipit');
-    my $tagbase = $shipit_conf->value('svk.tagpattern');
+    my $tagbase     = $shipit_conf->value('svk.tagpattern');
     if (defined $tagbase) {
 
         # svk.tagpattern will be the complete pattern, but we need the tag
         # base path. Usually it will be the last '/tags/' directory in the
         # pattern, so let's try to be smart.
-
         $tagbase =~ s!^(.*/tags)/.*$!$1!;
         return $tagbase;
     }
-
     return $self->app->config->{tagcheck};
 }
 
 sub run_single {
     my $self = shift;
-
     $self->SUPER::run_single(@_);
-
     my $tagbase = $self->get_tagbase;
     print "tagbase [$tagbase]\n" if $self->opt('verbose');
-
     my $svk = Dist::Joseki::SVK->new(
         tag_base         => $tagbase,
         changes_filename => $self->opt('file'),
     );
-
     if ($svk->dist_current_version_is_tagged) {
         print "Current version is tagged\n";
     } else {
@@ -80,25 +56,20 @@ sub run_single {
     }
 }
 
-
 sub hook_in_dist_loop_begin {
     my ($self, $dist) = @_;
     $self->SUPER::hook_in_dist_loop_begin($dist);
     $dist =~ s!.*/!!;
     print "$dist: ";
 }
-
-
 1;
-
-
 __END__
 
 
 
 =head1 NAME
 
-Dist::Joseki::Cmd::Command::tagcheck - 'tagcheck' command for Dist::Joseki::Cmd
+Dist::Joseki::Cmd::Command::tagcheck - Check whether the distribution is tagged
 
 =head1 SYNOPSIS
 
@@ -189,7 +160,7 @@ See perlmodinstall for information and options on installing Perl modules.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+site near you. Or see L<http://search.cpan.org/dist/Dist-Joseki/>.
 
 =head1 AUTHORS
 
@@ -197,7 +168,7 @@ Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by the authors.
+Copyright 2007-2009 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
