@@ -1,60 +1,48 @@
 package Dist::Joseki::Version;
-
 use strict;
 use warnings;
 use File::Find;
 use File::Slurp;
 use Module::Changes;
-
-
-our $VERSION = '0.17';
-
-
+our $VERSION = '0.18';
 use base qw(Dist::Joseki::Base);
 
-
 sub get_newest_version {
     my ($self, $changes_filename) = @_;
-
     die "can't find $changes_filename\n" unless -f $changes_filename;
     die "can't read $changes_filename\n" unless -e $changes_filename;
-
     Module::Changes->make_object_for_type('parser_yaml')
-        ->parse_from_file($changes_filename)
-        ->newest_release->version
+      ->parse_from_file($changes_filename)->newest_release->version;
 }
 
-
 sub set_version {
     my ($self, $version, @dir) = @_;
     $self->assert_is_dist_base_dir;
-
-    find(sub {
-        if ($_ eq '.svn') {
-            $File::Find::prune = 1;
-            return;
-        }
-
-        return unless -f && -r;
-        return if /\.swp$/;
-
-        my $contents = read_file($_);
-        if ($contents =~ s/(\$VERSION\s*=\s*([\'\"]))(.+?)\2/$1$version$2/) {
-            open my $fh, '>', $_ or
-                die "can't open $File::Find::name for writing: $!\n";
-            print $fh $contents;
-            close $fh or die "can't close $File::Find::name: $!\n";
-        } else {
-            warn "$File::Find::name: no \$VERSION line\n";
-        }
-    }, grep { -d $_ } @dir);
-
+    find(
+        sub {
+            if ($_ eq '.svn') {
+                $File::Find::prune = 1;
+                return;
+            }
+            return unless -f && -r;
+            return if /\.swp$/;
+            my $contents = read_file($_);
+            if ($contents =~ s/(\$VERSION\s*=\s*([\'\"]))(.+?)\2/$1$version$2/)
+            {
+                open my $fh, '>', $_
+                  or die "can't open $File::Find::name for writing: $!\n";
+                print $fh $contents;
+                close $fh or die "can't close $File::Find::name: $!\n";
+            } else {
+                warn "$File::Find::name: no \$VERSION line\n";
+            }
+        },
+        grep {
+            -d $_
+          } @dir
+    );
 }
-
-
 1;
-
-
 __END__
 
 
@@ -124,7 +112,7 @@ See perlmodinstall for information and options on installing Perl modules.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+site near you. Or see L<http://search.cpan.org/dist/Dist-Joseki/>.
 
 =head1 AUTHORS
 
@@ -132,7 +120,7 @@ Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by the authors.
+Copyright 2007-2009 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
